/* $Id: gkrellm-tz.c,v 1.1 2005/07/01 22:17:41 jirka Exp $ */
/*
 * Timezone plugin for GKrellM.
 * Copyright (C) 2005 Jiri Denemark
 *
 * This file is part of gkrellm-tz.
 *
 * gkrellm-tz is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/** @file
 * Timezone plugin for GKrellM.
 * @author Jiri Denemark
 * @date 2005
 * @version $Revision: 1.1 $ $Date: 2005/07/01 22:17:41 $
 */

#include <time.h>
#include <glib.h>
#include <gtk/gtk.h>
#include <gkrellm2/gkrellm.h>

#include "list.h"
#include "config.h"

#if (GKRELLM_VERSION_MAJOR < 2)
# error This plugin requires GKrellM version >= 2.0
#endif

#define CONFIG_TAB      "Timezone"
#define CONFIG_KEYWORD  "timezone"
#define PLACEMENT       (MON_CLOCK | MON_INSERT_AFTER)

#define GTK_DISABLE_DEPRECATED


static struct tz_plugin plugin;


static gint panel_expose_event(GtkWidget *widget, GdkEventExpose *ev)
{
    struct tz_list_item *item;

    for (item = plugin.first; item != NULL; item = item->next) {
        if (item->tz.enabled && widget == item->panel->drawing_area) {
            gdk_draw_pixmap(widget->window,
                            widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
                            item->panel->pixmap, ev->area.x, ev->area.y,
                            ev->area.x, ev->area.y, ev->area.width,
                            ev->area.height);
        }
    }

    return FALSE;
}


static void panel_click_event(GtkWidget *widget,
                              GdkEventButton *ev,
                              gpointer data)
{
    if (ev->button == 3)
        gkrellm_open_config_window(plugin.monitor);
}


static void update(void)
{
    if (gkrellm_ticks()->second_tick)
        tz_list_update(&plugin, mktime(gkrellm_get_current_time()));

    tz_plugin_update(&plugin);
}


static void create(GtkWidget *vbox, gint first_create)
{
    if (first_create) {
        plugin.vbox = vbox;

        tz_list_clean(&plugin);
        tz_list_load(&plugin);
    }
    else {
        struct tz_list_item *item;

        for (item = plugin.first; item != NULL; item = item->next) {
            if (item->tz.enabled)
                tz_panel_create(&plugin, item);
        }
    }
}


static void config(GtkWidget *tab_vbox)
{
    config_create_tabs(tab_vbox, &plugin);
}


static void apply(void)
{
    tz_list_clean(&plugin);
    config_list(&plugin);
    tz_list_store(&plugin);
}


static GkrellmMonitor plugin_mon = {
    CONFIG_TAB,                 /* Title for config tab. */
    0,                          /* Id,  0 if a plugin */
    create,                     /* The create function */
    update,                     /* The update function */
    config,                     /* The config tab create function */
    apply,                      /* Apply the config function */

    NULL,                       /* Save user config */
    NULL,                       /* Load user config */
    CONFIG_KEYWORD,             /* Config file keyword */

    NULL,                       /* Undefined 2 */
    NULL,                       /* Undefined 1 */
    NULL,                       /* Undefined 0 */

    PLACEMENT,                  /* Plugin placement */

    NULL,                       /* Handle if a plugin, filled in by GKrellM */
    NULL                        /* path if a plugin, filled in by GKrellM */
};


/** Plugin's entry point. */
GkrellmMonitor *gkrellm_init_plugin(void)
{
    plugin.first = NULL;
    plugin.last = NULL;
    plugin.vbox = NULL;
    plugin.tooltips = gtk_tooltips_new();
    gtk_tooltips_set_delay(plugin.tooltips, 500);
    plugin.monitor = &plugin_mon;
    plugin.expose_event = panel_expose_event;
    plugin.click_event = panel_click_event;

    return plugin.monitor;
}

